| Maintainer | dennis@felsin9.de |
|---|---|
| Safe Haskell | Safe-Inferred |
Graphics.XDot.Types
Description
This module contains various types used to represent xdot parameters.
- type Point = (Double, Double)
- type Rectangle = (Double, Double, Double, Double)
- data Alignment
- = LeftAlign
- | CenterAlign
- | RightAlign
- data Object n
- data Operation
Documentation
type Rectangle = (Double, Double, Double, Double)Source
A rectangle, x and y position, width and height.
An object an operation can belong to.
Drawing operations supported by xdot. See http://www.graphviz.org/doc/info/output.html#d:xdot for more information
Constructors
| Ellipse | |
| Polygon | |
| Polyline | |
| BSpline | |
| FontCharacteristics | |
Fields
| |
| Text | |
| Color | |
| Font | |
| Style | |
Fields
| |
| Image | |
Instances
| Show Operation |